aboutsummaryrefslogtreecommitdiffstats
path: root/components/model-catalog/proto-definition
diff options
context:
space:
mode:
authorJozsef Csongvai <jozsef.csongvai@bell.ca>2021-07-26 12:00:59 -0400
committerJozsef Csongvai <jozsef.csongvai@bell.ca>2021-07-28 15:44:01 -0400
commitdaab14bd058de198c80b71d63e108fd788b7f5ee (patch)
tree252cfdef5b2e1500e5bd152f3f5c52602b6b0deb /components/model-catalog/proto-definition
parent82e396d6917519468376d177dd6a2710e84fa23a (diff)
Revert "Renaming Files having BluePrint to have Blueprint"
The renaming in CCSDK-3098 caused breaking changes to the grpc api and compile issues for kotlin scripts. Issue-ID: CCSDK-3385 Change-Id: I0d745cb858371678eabcb2284671c1fd76a1ab6d Signed-off-by: Jozsef Csongvai <jozsef.csongvai@bell.ca>
Diffstat (limited to 'components/model-catalog/proto-definition')
-rw-r--r--components/model-catalog/proto-definition/proto/BluePrintCommon.proto (renamed from components/model-catalog/proto-definition/proto/BlueprintCommon.proto)0
-rw-r--r--components/model-catalog/proto-definition/proto/BluePrintManagement.proto (renamed from components/model-catalog/proto-definition/proto/BlueprintManagement.proto)24
-rw-r--r--components/model-catalog/proto-definition/proto/BluePrintProcessing.proto (renamed from components/model-catalog/proto-definition/proto/BlueprintProcessing.proto)4
3 files changed, 14 insertions, 14 deletions
diff --git a/components/model-catalog/proto-definition/proto/BlueprintCommon.proto b/components/model-catalog/proto-definition/proto/BluePrintCommon.proto
index ce90929dc..ce90929dc 100644
--- a/components/model-catalog/proto-definition/proto/BlueprintCommon.proto
+++ b/components/model-catalog/proto-definition/proto/BluePrintCommon.proto
diff --git a/components/model-catalog/proto-definition/proto/BlueprintProcessing.proto b/components/model-catalog/proto-definition/proto/BluePrintProcessing.proto
index 3e8bfd8c4..9622287ab 100644
--- a/components/model-catalog/proto-definition/proto/BlueprintProcessing.proto
+++ b/components/model-catalog/proto-definition/proto/BluePrintProcessing.proto
@@ -1,6 +1,6 @@
syntax = "proto3";
import "google/protobuf/struct.proto";
-import "BlueprintCommon.proto";
+import "BluePrintCommon.proto";
option java_multiple_files = true;
package org.onap.ccsdk.cds.controllerblueprints.processing.api;
@@ -19,6 +19,6 @@ message ExecutionServiceOutput {
}
-service BlueprintProcessingService {
+service BluePrintProcessingService {
rpc process (stream ExecutionServiceInput) returns (stream ExecutionServiceOutput);
}
diff --git a/components/model-catalog/proto-definition/proto/BlueprintManagement.proto b/components/model-catalog/proto-definition/proto/BluePrintManagement.proto
index 3b6d43f3e..a363e8ade 100644
--- a/components/model-catalog/proto-definition/proto/BlueprintManagement.proto
+++ b/components/model-catalog/proto-definition/proto/BluePrintManagement.proto
@@ -1,10 +1,10 @@
syntax = "proto3";
import "google/protobuf/struct.proto";
-import "BlueprintCommon.proto";
+import "BluePrintCommon.proto";
option java_multiple_files = true;
package org.onap.ccsdk.cds.controllerblueprints.management.api;
-message BlueprintUploadInput {
+message BluePrintUploadInput {
org.onap.ccsdk.cds.controllerblueprints.common.api.CommonHeader commonHeader = 1;
FileChunk fileChunk = 2;
org.onap.ccsdk.cds.controllerblueprints.common.api.ActionIdentifiers actionIdentifiers = 3;
@@ -12,28 +12,28 @@ message BlueprintUploadInput {
google.protobuf.Struct properties = 4;
}
-message BlueprintDownloadInput {
+message BluePrintDownloadInput {
org.onap.ccsdk.cds.controllerblueprints.common.api.CommonHeader commonHeader = 1;
org.onap.ccsdk.cds.controllerblueprints.common.api.ActionIdentifiers actionIdentifiers = 2;
// Extra optional dynamic properties used to download.
google.protobuf.Struct properties = 3;
}
-message BlueprintRemoveInput {
+message BluePrintRemoveInput {
org.onap.ccsdk.cds.controllerblueprints.common.api.CommonHeader commonHeader = 1;
org.onap.ccsdk.cds.controllerblueprints.common.api.ActionIdentifiers actionIdentifiers = 2;
// Extra optional dynamic properties used to remove.
google.protobuf.Struct properties = 3;
}
-message BlueprintBootstrapInput {
+message BluePrintBootstrapInput {
org.onap.ccsdk.cds.controllerblueprints.common.api.CommonHeader commonHeader = 1;
bool loadCBA = 2;
bool loadModelType = 3;
bool loadResourceDictionary = 4;
}
-message BlueprintManagementOutput {
+message BluePrintManagementOutput {
org.onap.ccsdk.cds.controllerblueprints.common.api.CommonHeader commonHeader = 1;
// Optional file chunk sent back to the client for Enrich and Download this is mandatory.
FileChunk fileChunk = 2;
@@ -45,7 +45,7 @@ message BlueprintManagementOutput {
message FileChunk {
bytes chunk = 1;
}
// Values used in BlueprintDownloadInput/actionIdentifiers/action
enum DownloadAction {
// Default is SEARCH the cba and download the cba
SEARCH = 0;
@@ -68,9 +68,9 @@ enum RemoveAction {
DEFAULT = 0;
}
-service BlueprintManagementService {
- rpc downloadBlueprint (BlueprintDownloadInput) returns (BlueprintManagementOutput);
- rpc uploadBlueprint (BlueprintUploadInput) returns (BlueprintManagementOutput);
- rpc removeBlueprint (BlueprintRemoveInput) returns (BlueprintManagementOutput);
- rpc bootstrapBlueprint (BlueprintBootstrapInput) returns (BlueprintManagementOutput);
+service BluePrintManagementService {
+ rpc downloadBlueprint (BluePrintDownloadInput) returns (BluePrintManagementOutput);
+ rpc uploadBlueprint (BluePrintUploadInput) returns (BluePrintManagementOutput);
+ rpc removeBlueprint (BluePrintRemoveInput) returns (BluePrintManagementOutput);
+ rpc bootstrapBlueprint (BluePrintBootstrapInput) returns (BluePrintManagementOutput);
}
@@ -45,7 +45,7 @@ message BlueprintManagementOutput {
bytes chunk = 1;
}
-// Values used in BlueprintDownloadInput/actionIdentifiers/action
+// Values used in BluePrintDownloadInput/actionIdentifiers/action
enum DownloadAction {
// Default is SEARCH the cba and download the cba